// **********************************************************************
//
// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

#include <sstream>
#include <Ice/Ice.h>
#include <OmniaUITestInterface.h>

using namespace std;
using namespace OmniaUITest;

void TestGetShiftRegister( OmniaUITestInterfacePrx aProxy )
{
  ::OmniaUITest::ShiftRegister lShiftRegister;
  ::OmniaUITest::ShiftRegisterRow lShiftRegisterRow;
  ::OmniaUITest::EggInformation lEggInformation;
  int lRowCnt;
  int lColumnCnt;

  lShiftRegister = aProxy->GetShiftRegister();
  lRowCnt = lShiftRegister.size();
  lColumnCnt = lShiftRegister[ 0 ].size();

  cout << endl << "GetShiftRegister(): Display contents of shiftregister with " << lRowCnt << " rows and " << lColumnCnt << " columns." << endl;

  ::OmniaUITest::ShiftRegister::iterator lRowIterator;
  ::OmniaUITest::ShiftRegisterRow::iterator lColumnIterator;
  cout << endl << "  Display row and column indexes:" << endl;
  for( lRowIterator = lShiftRegister.begin(); lRowIterator < lShiftRegister.end(); lRowIterator++ )
  {
    lShiftRegisterRow = *lRowIterator;
    cout << "    R:" << (short)(lShiftRegisterRow[ 0 ].RowCode);

    for( lColumnIterator = lShiftRegisterRow.begin(); lColumnIterator < lShiftRegisterRow.end(); lColumnIterator++ )
    {
      lEggInformation = *lColumnIterator;
      cout << "   C:" << (short)(lEggInformation.ColumnCode);
    }
    cout << endl;
  }
}

int
main( int argc, char* argv[] )
{
  int status = 0;

  Ice::CommunicatorPtr ic;

  try 
  {
    ic = Ice::initialize( argc, argv );

    Ice::ObjectPrx ModuleProxy = ic->propertyToProxy( "OmniaUITest.Proxy" );
    OmniaUITestInterfacePrx OmniaUITestInterfaceProxy = \
      OmniaUITestInterfacePrx::checkedCast(ModuleProxy);
    if( !OmniaUITestInterfaceProxy )
    {
      cerr << "Invalid proxy to interface OmniaUITest specified" << endl;
    }
    else
    {

 	// Try some calls on the interface of the server
  	cout << endl << endl;
	TestGetShiftRegister( OmniaUITestInterfaceProxy );
    }

    cout << endl << endl << "Press any key to finish!" << endl;
    const int LINE_SIZE = 80;
    char Line[ LINE_SIZE ];
    cin.getline( Line, LINE_SIZE );
  }
  catch (const Ice::Exception& e)
  {
    cerr << e << endl;
    status = 1;
  }
  catch(const char* msg)
  {
    cerr << msg << endl;
    status = 1;
  }

  if( ic )
  {
    try
    {
      ic->destroy();
    }
    catch( const Ice::Exception& e )
    {
      cerr << e << endl;
      status = 1;
    }
  }

  return status;
}


